@@ -1,5 +1,5 @@
 package POE::Component::Client::Whois::TLDList;
-$POE::Component::Client::Whois::TLDList::VERSION = '1.32';
+$POE::Component::Client::Whois::TLDList::VERSION = '1.34';
 #ABSTRACT: Determine the applicable Whois server for a given Top-level domain (TLD).
 
 use strict;
@@ -949,7 +949,7 @@ my %data = (
                      'whois.isnet.is'
                    ],
           '.de' => [
-                     'whois.denic.de'
+                     'de.whois-servers.net'
                    ],
           '.mh' => [
                      'NONE'
@@ -1180,7 +1180,7 @@ POE::Component::Client::Whois::TLDList - Determine the applicable Whois server f
 
 =head1 VERSION
 
-version 1.32
+version 1.34
 
 =head1 SYNOPSIS
 
